@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -92,12 +92,6 @@ public: /* Methods: */
     */
     void addModules(BtModuleSet const & modules);
 
-    /**
-      Appends the all the modules in the given list to this model.
-      \param[in] modules Set of modules to add.
-    */
-    void addModules(const QList<CSwordModuleInfo *> & modules);
-
     /**
       Removes the given module from this model and optionally destroys it.
       \param[in] module The module to remove from this model.
