@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -81,8 +81,8 @@ public: /* Types: */
                 push_back(GROUP_LANGUAGE);
             }
 
-            inline Grouping(const Grouping & copy)
-                : QList<Group>(copy) {}
+            inline Grouping(Grouping const & copy) = default;
+            inline Grouping & operator=(Grouping const & copy) = default;
 
             bool loadFrom(const QString & configKey);
             void saveTo(const QString & configKey) const;
