@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -21,7 +22,7 @@ class BtModuleSet: public QSet<CSwordModuleInfo *> {
 
 public: /* Methods: */
 
-    inline BtModuleSet() {};
+    inline BtModuleSet() {}
 
     inline BtModuleSet(QSet<CSwordModuleInfo *> const & copy)
         : QSet<CSwordModuleInfo *>(copy)
