@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -32,8 +35,8 @@ CTextRendering::KeyTreeItem::KeyTreeItem(const QString &key,
         m_moduleList(),
         m_key( key ),
         m_childList(),
-        m_stopKey( QString::null ),
-        m_alternativeContent( QString::null ) {
+        m_stopKey( QString() ),
+        m_alternativeContent( QString() ) {
     m_moduleList.append( const_cast<CSwordModuleInfo*>(module) ); //BAD CODE
 }
 
@@ -41,9 +44,9 @@ CTextRendering::KeyTreeItem::KeyTreeItem(const QString &content,
                                          const Settings &settings)
         : m_settings( settings ),
         m_moduleList(),
-        m_key( QString::null ),
+        m_key( QString() ),
         m_childList(),
-        m_stopKey( QString::null ),
+        m_stopKey( QString() ),
         m_alternativeContent( content ) {
 }
 
@@ -54,17 +57,17 @@ CTextRendering::KeyTreeItem::KeyTreeItem(const QString &key,
         m_moduleList( mods ),
         m_key( key ),
         m_childList(),
-        m_stopKey( QString::null ),
-        m_alternativeContent( QString::null ) {
+        m_stopKey( QString() ),
+        m_alternativeContent( QString() ) {
 }
 
 CTextRendering::KeyTreeItem::KeyTreeItem()
         : m_settings(),
         m_moduleList(),
-        m_key(QString::null),
+        m_key(QString()),
         m_childList(),
-        m_stopKey(QString::null),
-        m_alternativeContent(QString::null) {
+        m_stopKey(QString()),
+        m_alternativeContent(QString()) {
 }
 
 CTextRendering::KeyTreeItem::KeyTreeItem(const KeyTreeItem& i)
@@ -91,7 +94,7 @@ CTextRendering::KeyTreeItem::KeyTreeItem(const QString &startKey,
         m_key( startKey ),
         m_childList(),
         m_stopKey( stopKey ),
-        m_alternativeContent( QString::null ) {
+        m_alternativeContent( QString() ) {
     BT_ASSERT(module);
     m_moduleList.append(module);
 
@@ -109,22 +112,38 @@ CTextRendering::KeyTreeItem::KeyTreeItem(const QString &startKey,
 
             while (ok && ((start < stop) || (start == stop)) ) { //range
                 m_childList.append(
-                    new KeyTreeItem(start.key(), module, KeyTreeItem::Settings(false, settings.keyRenderingFace))
-                );
-
-
+                            new KeyTreeItem(start.key(),
+                                            module,
+                                            KeyTreeItem::Settings{
+                                                false,
+                                                settings.keyRenderingFace}));
                 ok = start.next(CSwordVerseKey::UseVerse);
             }
         }
         else if (m_key.isEmpty()) {
-            m_childList.append( new KeyTreeItem(startKey, module, KeyTreeItem::Settings(false, settings.keyRenderingFace)) );
+            m_childList.append(
+                        new KeyTreeItem(startKey,
+                                        module,
+                                        KeyTreeItem::Settings{
+                                            false,
+                                            settings.keyRenderingFace}));
         }
     }
     else if ((module->type() == CSwordModuleInfo::Lexicon) || (module->type() == CSwordModuleInfo::Commentary) ) {
-        m_childList.append( new KeyTreeItem(startKey, module, KeyTreeItem::Settings(false, KeyTreeItem::Settings::NoKey)) );
+        m_childList.append(
+                    new KeyTreeItem(startKey,
+                                    module,
+                                    KeyTreeItem::Settings{
+                                        false,
+                                        KeyTreeItem::Settings::NoKey}));
     }
     else if (module->type() == CSwordModuleInfo::GenericBook) {
-        m_childList.append( new KeyTreeItem(startKey, module, KeyTreeItem::Settings(false, KeyTreeItem::Settings::NoKey)) );
+        m_childList.append(
+                    new KeyTreeItem(startKey,
+                                    module,
+                                    KeyTreeItem::Settings{
+                                        false,
+                                        KeyTreeItem::Settings::NoKey}));
     }
 
     //make it into "<simple|range> (modulename)"
@@ -255,7 +274,7 @@ const QString CTextRendering::renderKeyRange(
         return renderKeyTree(tree);
     }
 
-    return QString::null;
+    return QString();
 }
 
 const QString CTextRendering::renderSingleKey(
