@@ -1,18 +1,22 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/crossrefrendering.h"
+#include "crossrefrendering.h"
 
-#include "backend/drivers/cswordmoduleinfo.h"
-#include "backend/keys/cswordversekey.h"
-#include "backend/managers/referencemanager.h"
-#include "util/btassert.h"
+#include <QtGlobal>
+#include "../backend/drivers/cswordmoduleinfo.h"
+#include "../backend/keys/cswordversekey.h"
+#include "../backend/managers/referencemanager.h"
+#include "../util/btassert.h"
 
 
 namespace InfoDisplay {
@@ -42,31 +46,30 @@ QString CrossRefRendering::entryLink(const KeyTreeItem &item,
     }
 
     switch (item.settings().keyRenderingFace) {
-        case KeyTreeItem::Settings::NoKey: {
-            linkText = QString::null;
+        case KeyTreeItem::Settings::NoKey:
+            linkText = QString();
             break; //no key is valid for all modules
-        }
-        case KeyTreeItem::Settings::CompleteShort: {
+        case KeyTreeItem::Settings::CompleteShort:
             if (isBible) {
                 linkText = QString::fromUtf8(vk.getShortText());
                 break;
             }
             //fall through for non-Bible modules
-        }
-        case KeyTreeItem::Settings::CompleteLong: {
+            Q_FALLTHROUGH();
+        case KeyTreeItem::Settings::CompleteLong:
             if (isBible) {
                 linkText = vk.key();
                 break;
             }
             //fall through for non-Bible modules
-        }
-        case KeyTreeItem::Settings::SimpleKey: {
+            Q_FALLTHROUGH();
+        case KeyTreeItem::Settings::SimpleKey:
             if (isBible) {
                 linkText = QString::number(vk.getVerse());
                 break;
             }
             //fall through for non-Bible modules
-        }
+            Q_FALLTHROUGH();
         default: { //default behaviour to return the passed key
             linkText = item.key();
             break;
@@ -86,7 +89,7 @@ QString CrossRefRendering::entryLink(const KeyTreeItem &item,
                .arg(linkText);
     }
 
-    return QString::null;
+    return QString();
 }
 
 }
