@@ -2,18 +2,19 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2014 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
 #ifndef INFODISPLAYCROSSREFRENDERING_H
 #define INFODISPLAYCROSSREFRENDERING_H
 
-#include "backend/rendering/chtmlexportrendering.h"
-#include "backend/config/btconfig.h"
+#include "../backend/rendering/chtmlexportrendering.h"
+#include "../backend/config/btconfig.h"
 
 
 namespace InfoDisplay {
@@ -27,10 +28,10 @@ class CrossRefRendering : public Rendering::CHTMLExportRendering {
             const FilterOptions &filterOptions = btConfig().getFilterOptions()
         );
 
-        virtual QString entryLink(const KeyTreeItem &item,
-                                  const CSwordModuleInfo *module);
+        QString entryLink(const KeyTreeItem &item,
+                          const CSwordModuleInfo *module) override;
 
-        virtual QString finishText(const QString &text, const KeyTree &tree);
+        QString finishText(const QString &text, const KeyTree &tree) override;
 };
 
 
