@@ -13,6 +13,7 @@
 
 #include <QApplication>
 #include <QClipboard>
+#include <QQuickItem>
 #include <QScreen>
 #include <QTimer>
 #include "../../../backend/config/btconfig.h"
@@ -33,10 +34,6 @@
 #include "../../cinfodisplay.h"
 #include "../../edittextwizard/btedittextwizard.h"
 
-// Sword includes:
-#include <swkey.h>
-
-
 
 BtQmlInterface::BtQmlInterface(QObject* parent)
     : QObject(parent),
@@ -44,6 +41,7 @@ BtQmlInterface::BtQmlInterface(QObject* parent)
       m_linkTimer(new QTimer(this)),
       m_moduleTextModel(new BtModuleTextModel(this)),
       m_swordKey(nullptr),
+      m_backgroundHighlightColorIndex(-1),
       m_caseSensitive(false) {
 
     m_moduleTextModel->setTextFilter(&m_textFilter);
@@ -96,6 +94,15 @@ void BtQmlInterface::setContextMenuIndex(int index) {
     emit contextMenuIndexChanged();
 }
 
+int BtQmlInterface::getContextMenuColumn() const {
+    return m_contextMenuColumn;
+}
+
+void BtQmlInterface::setContextMenuColumn(int index) {
+    m_contextMenuColumn = index;
+    emit contextMenuColumnChanged();
+}
+
 QString BtQmlInterface::getActiveLink() const {
     return m_activeLink;
 }
@@ -109,6 +116,14 @@ QColor BtQmlInterface::getBackgroundColor() const {
     return ColorManager::instance().getBackgroundColor();
 }
 
+QColor BtQmlInterface::getBackgroundHighlightColor() const {
+    return ColorManager::instance().getBackgroundHighlightColor();
+}
+
+int BtQmlInterface::getBackgroundHighlightColorIndex() const {
+    return m_backgroundHighlightColorIndex;
+}
+
 QColor BtQmlInterface::getForegroundColor() const {
     return ColorManager::instance().getForegroundColor();
 }
@@ -185,8 +200,8 @@ QString BtQmlInterface::getRawText(int row, int column) {
 
 void BtQmlInterface::openEditor(int row, int column) {
     BtEditTextWizard wiz;
-    QString verse = m_moduleTextModel->indexToKeyName(row);
-    wiz.setTitle(tr("Edit") + " " + verse);
+    QString keyName = m_moduleTextModel->indexToKeyName(row);
+    wiz.setTitle(tr("Edit") + " " + keyName);
     wiz.setText(getRawText(row,column));
     QFont font = m_fonts.at(column);
     wiz.setFont(font);
@@ -197,6 +212,10 @@ void BtQmlInterface::openEditor(int row, int column) {
     return;
 }
 
+int BtQmlInterface::indexToVerse(int index) {
+    return m_moduleTextModel->indexToVerse(index);
+}
+
 void BtQmlInterface::openContextMenu(int x, int y, int width) {
     double xRatio = x / static_cast<double>(width);
     int column = int(xRatio * m_moduleNames.count());
@@ -267,16 +286,14 @@ QString BtQmlInterface::getReferenceFromUrl(const QString& url) {
 
 void BtQmlInterface::setRawText(int row, int column, const QString& text) {
     QModelIndex index = m_moduleTextModel->index(row, 0);
-    int role = ModuleEntry::Text1Role;
-    if (column == 1)
-        role = ModuleEntry::Text2Role;
-    else if (column == 2)
-        role = ModuleEntry::Text3Role;
-    else if (column == 3)
-        role = ModuleEntry::Text4Role;
+    int role = ModuleEntry::Text0Role + column;
     m_moduleTextModel->setData(index, text, role);
 }
 
+void BtQmlInterface::cancelMagTimer() {
+    m_linkTimer->stop();
+}
+
 void BtQmlInterface::setMagReferenceByUrl(const QString& url) {
     if (url.isEmpty())
         return;
@@ -335,7 +352,24 @@ void BtQmlInterface::setKey( CSwordKey* key ) {
     m_swordKey = key;
 }
 
+void BtQmlInterface::setKeyFromLink(const QString& link) {
+    QRegExp rx("sword://Bible/(.*)/(.*)\\|\\|(.*)=(.*)");
+    rx.setMinimal(false);
+    int pos1 = rx.indexIn(link);
+    QString keyName;
+    if (pos1 > -1) {
+        keyName = rx.cap(2);
+        Q_EMIT newBibleReference(keyName);
+    }
+}
+
 void BtQmlInterface::scrollToSwordKey(CSwordKey * key) {
+    m_backgroundHighlightColorIndex = m_moduleTextModel->keyToIndex(key);
+
+    /* Convert from sword index to ListView index */
+    m_backgroundHighlightColorIndex = m_backgroundHighlightColorIndex - m_moduleTextModel->getFirstEntryIndex();
+
+    emit backgroundHighlightColorIndexChanged();
     m_swordKey = key;
     emit currentModelIndexChanged();
 }
@@ -349,7 +383,6 @@ void BtQmlInterface::setModules(const QStringList &modules) {
 
 void BtQmlInterface::referenceChosen() {
     emit referenceChange();
-    //    updateModel();
     emit currentModelIndexChanged();
 }
 
@@ -388,52 +421,26 @@ CSwordKey* BtQmlInterface::getKey() const {
     return m_swordKey;
 }
 
-QString BtQmlInterface::fontName(int column) const {
+CSwordKey* BtQmlInterface::getMouseClickedKey() const {
+    return m_moduleTextModel->indexToKey(m_contextMenuIndex, m_contextMenuColumn);
+}
+
+QFont BtQmlInterface::font(int column) const {
     if (column >= 0 && column < m_fonts.count())
-        return m_fonts.at(column).family();
-    return QApplication::font().family();
+        return m_fonts.at(column);
+    return QApplication::font();
 }
 
-QString BtQmlInterface::getFontName0() const {
-    return fontName(0);
-}
-
-QString BtQmlInterface::getFontName1() const {
-    return fontName(1);
-}
-
-QString BtQmlInterface::getFontName2() const {
-    return fontName(2);
-}
-
-QString BtQmlInterface::getFontName3() const {
-    return fontName(3);
-}
-
-int BtQmlInterface::getFontSize0()const {
-    return fontSize(0);
-}
-
-int BtQmlInterface::getFontSize1()const {
-    return fontSize(1);
-}
-
-int BtQmlInterface::getFontSize2()const {
-    return fontSize(2);
-}
-
-int BtQmlInterface::getFontSize3()const {
-    return fontSize(3);
-}
-
-
-int BtQmlInterface::fontSize(int column) const {
-    if (column >= 0 && column < m_fonts.count()) {
-        int size = m_fonts.at(column).pointSize();
-        return size;
-    }
-    return QApplication::font().pointSize();
-}
+QFont BtQmlInterface::getFont0() const { return font(0); }
+QFont BtQmlInterface::getFont1() const { return font(1); }
+QFont BtQmlInterface::getFont2() const { return font(2); }
+QFont BtQmlInterface::getFont3() const { return font(3); }
+QFont BtQmlInterface::getFont4() const { return font(4); }
+QFont BtQmlInterface::getFont5() const { return font(5); }
+QFont BtQmlInterface::getFont6() const { return font(6); }
+QFont BtQmlInterface::getFont7() const { return font(7); }
+QFont BtQmlInterface::getFont8() const { return font(8); }
+QFont BtQmlInterface::getFont9() const { return font(9); }
 
 QString BtQmlInterface::getSelectedText() {
 
@@ -474,22 +481,6 @@ void BtQmlInterface::configModuleByType(const QString& type, const QStringList&
     }
 }
 
-#if 0
-bool BtQmlInterface::isCopyToLarge(const QString& ref1, const QString& ref2) {
-    RefIndexes ri = normalizeReferences(ref1, ref2);
-    CSwordModuleInfo::ModuleType type = m_swordKey->module()->type();
-    if (type == CSwordModuleInfo::Bible ||
-            type == CSwordModuleInfo::Commentary) {
-        if ((ri.index2-ri.index1) > 2500)
-            return true;
-    } else {
-        if ( ri.index2-ri.index1 > 25)
-            return true;
-    }
-    return false;
-}
-#endif
-
 RefIndexes BtQmlInterface::normalizeReferences(const QString& ref1, const QString& ref2) {
     RefIndexes ri;
     CSwordKey * key = m_swordKey->copy();
@@ -509,6 +500,7 @@ RefIndexes BtQmlInterface::normalizeReferences(const QString& ref1, const QStrin
 }
 
 void BtQmlInterface::changeColorTheme() {
+    emit backgroundHighlightColorChanged();
     emit backgroundColorChanged();
     emit foregroundColorChanged();
 }
@@ -700,21 +692,8 @@ void BtQmlInterface::getPreviousMatchingItem(int startIndex) {
     return;
 }
 
-void BtQmlInterface::deSelect() {
-    m_moduleTextModel->deSelect();
-    clearSelectedText();
-}
-
-bool BtQmlInterface::isSelected() {
-    return m_moduleTextModel->isSelected();
-}
-
-void BtQmlInterface::selectByIndex(int first, int last,
-                                   int column,
-                                   int posFirst, int posLast) {
-    m_moduleTextModel->selectByIndex(first, last,
-                                     column,
-                                     posFirst, posLast);
+bool BtQmlInterface::hasSelectedText() {
+    return ! m_selectedText.isEmpty();
 }
 
 void BtQmlInterface::clearSelectedText() {
@@ -729,3 +708,12 @@ bool BtQmlInterface::shiftKeyDown() {
     return QGuiApplication::keyboardModifiers() & Qt::ShiftModifier;
 }
 
+void BtQmlInterface::setBoundsMovement() {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QQuickItem* displayListView = parent()->findChild<QQuickItem*>("DisplayListView");
+    if (displayListView != nullptr) {
+        int StopAtBounds = 0;
+        displayListView->setProperty("boundsMovement", StopAtBounds);
+    }
+#endif
+}
