@@ -29,6 +29,7 @@
 #include "../cmdiarea.h"
 #include "../display/btmodelviewreaddisplay.h"
 #include "../display/modelview/btqmlinterface.h"
+#include "../display/modelview/btquickwidget.h"
 #include "../searchdialog/csearchdialog.h"
 #include "btactioncollection.h"
 
@@ -117,10 +118,12 @@ void CReadWindow::resizeEvent(QResizeEvent * e) {
 
 void CReadWindow::openSearchStrongsDialog() {
     QString searchText;
-    Q_FOREACH(QString const & strongNumber,
-              displayWidget()->getCurrentNodeInfo().split(
-                  '|',
-                  QString::SkipEmptyParts))
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    QStringList nodeInfo = displayWidget()->getCurrentNodeInfo().split('|', QString::SkipEmptyParts);
+#else
+    QStringList nodeInfo = displayWidget()->getCurrentNodeInfo().split('|', Qt::SkipEmptyParts);
+#endif
+    Q_FOREACH(QString const& strongNumber, nodeInfo)
         searchText.append("strong:").append(strongNumber).append(' ');
     Search::CSearchDialog::openDialog(modules(), searchText, nullptr);
 }
@@ -157,7 +160,7 @@ void CReadWindow::copyByReferences() {
     if (BtModelViewReadDisplay * const v =
             dynamic_cast<BtModelViewReadDisplay *>(m_readDisplayWidget)) {
         auto model = v->qmlInterface()->textModel();
-        BtCopyByReferencesDialog  dlg(modules(), history(), key(), model, this);        
+        BtCopyByReferencesDialog  dlg(modules(), history(), key(), model, this);
         int rtn = dlg.exec();
         if (rtn == QDialog::Rejected)
             return;
@@ -177,9 +180,40 @@ void CReadWindow::copyByReferences() {
 bool CReadWindow::hasSelectedText() {
     if (BtModelViewReadDisplay * const v =
             dynamic_cast<BtModelViewReadDisplay *>(m_readDisplayWidget)) {
-        auto model = v->qmlInterface()->textModel();
-        return model->hasSelectedText();
+        bool selected = v->qmlInterface()->hasSelectedText();
+        return selected;
     }
     return false;
 }
 
+int CReadWindow::getSelectedColumn() const {
+    if (BtModelViewReadDisplay * const v =
+            dynamic_cast<BtModelViewReadDisplay *>(m_readDisplayWidget)) {
+        return  v->quickWidget()->getSelectedColumn();
+    }
+    return 0;
+}
+
+int CReadWindow::getFirstSelectedIndex() const {
+    if (BtModelViewReadDisplay * const v =
+            dynamic_cast<BtModelViewReadDisplay *>(m_readDisplayWidget)) {
+        return  v->quickWidget()->getFirstSelectedIndex();
+    }
+    return 0;
+}
+
+int CReadWindow::getLastSelectedIndex() const {
+    if (BtModelViewReadDisplay * const v =
+            dynamic_cast<BtModelViewReadDisplay *>(m_readDisplayWidget)) {
+        return  v->quickWidget()->getLastSelectedIndex();
+    }
+    return 0;
+}
+
+CSwordKey* CReadWindow::getMouseClickedKey() const {
+    if (BtModelViewReadDisplay * const v =
+            dynamic_cast<BtModelViewReadDisplay *>(m_readDisplayWidget)) {
+        return  v->quickWidget()->getMouseClickedKey();
+    }
+    return 0;
+}
