@@ -2,20 +2,21 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
 #ifndef CBIBLEKEYCHOOSER_H
 #define CBIBLEKEYCHOOSER_H
 
-#include "frontend/keychooser/ckeychooser.h"
+#include "../ckeychooser.h"
 
 #include <QList>
-#include "backend/drivers/cswordbiblemoduleinfo.h"
+#include "../../../backend/drivers/cswordbiblemoduleinfo.h"
 
 
 class QWidget;
