@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/searchdialog/analysis/csearchanalysisitem.h"
+#include "csearchanalysisitem.h"
 
 #include <QFont>
 #include <QGraphicsRectItem>
@@ -15,8 +18,8 @@
 #include <QPen>
 #include <QPoint>
 #include <QRect>
-#include "backend/drivers/cswordmoduleinfo.h"
-#include "frontend/searchdialog/analysis/csearchanalysisscene.h"
+#include "../../../backend/drivers/cswordmoduleinfo.h"
+#include "csearchanalysisscene.h"
 
 
 namespace Search {
@@ -142,7 +145,7 @@ const QString CSearchAnalysisItem::getToolTip() {
                              : 0.0;
         toolTipString.append("<tr bgcolor=\"white\"><td><b><font color=\"")
                      .append(CSearchAnalysisScene::getColor(i).name()).append("\">")
-                     .append(info ? info->name() : QString::null)
+                     .append(info ? info->name() : QString())
                      .append("</font></b></td><td>")
                      .append(m_resultCountArray.at(i))
                      .append(" (")
