@@ -20,7 +20,6 @@
 #include <QSize>
 #include <QSplitter>
 #include <QStringList>
-#include <QTextBrowser>
 #include <QVBoxLayout>
 #include <QWidget>
 #include "../../backend/config/btconfig.h"
@@ -87,8 +86,7 @@ void BtSearchResultArea::initView() {
 
     QVBoxLayout* frameLayout = new QVBoxLayout(m_displayFrame);
     frameLayout->setContentsMargins(0, 0, 0, 0);
-    m_previewDisplay = new QTextBrowser(this);
-    m_previewDisplay->setOpenLinks(false);
+    m_previewDisplay = new BtTextBrowser(this);
     m_previewDisplay->setToolTip(tr("Text of the selected search result item"));
     frameLayout->addWidget(m_previewDisplay);
 
