@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -16,7 +17,7 @@
 
 class QDialogButtonBox;
 class QUrl;
-class BtWebEngineView;
+class QTextBrowser;
 
 namespace Search {
 
@@ -32,7 +33,7 @@ class BtSearchSyntaxHelpDialog: public QDialog {
         void linkClicked(const QUrl &url);
 
     private:
-        BtWebEngineView  *m_webView;
+        QTextBrowser  *m_textBrowser;
         QDialogButtonBox *m_buttons;
 };
 
