@@ -1,20 +1,23 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/settingsdialogs/bttextfilterstab.h"
+#include "bttextfilterstab.h"
 
 #include <QCheckBox>
 #include <QLabel>
 #include <QVBoxLayout>
-#include "backend/config/btconfig.h"
-#include "frontend/settingsdialogs/cswordsettings.h"
-#include "util/tool.h"
+#include "../../backend/config/btconfig.h"
+#include "../../util/tool.h"
+#include "cswordsettings.h"
 
 
 #define TEXT_FILTERS_TAB_ADD_ROW(name,def) \
@@ -35,8 +38,7 @@ BtTextFiltersTab::BtTextFiltersTab(CSwordSettingsPage *parent)
     layout->addWidget(m_explanationLabel);
 
     btConfig().beginGroup("presentation");
-        TEXT_FILTERS_TAB_ADD_ROW(lineBreaks, false);
-        TEXT_FILTERS_TAB_ADD_ROW(verseNumbers, false);
+        TEXT_FILTERS_TAB_ADD_ROW(verseNumbers, true);
         TEXT_FILTERS_TAB_ADD_ROW(headings, true);
         TEXT_FILTERS_TAB_ADD_ROW(hebrewPoints, true);
         TEXT_FILTERS_TAB_ADD_ROW(hebrewCantillation, true);
@@ -56,7 +58,6 @@ BtTextFiltersTab::BtTextFiltersTab(CSwordSettingsPage *parent)
 
 void BtTextFiltersTab::save() {
     btConfig().beginGroup("presentation");
-        TEXT_FILTERS_TAB_SAVE(lineBreaks);
         TEXT_FILTERS_TAB_SAVE(verseNumbers);
         TEXT_FILTERS_TAB_SAVE(headings);
         TEXT_FILTERS_TAB_SAVE(hebrewPoints);
@@ -76,7 +77,6 @@ void BtTextFiltersTab::retranslateUi() {
              "opened display windows only. You can override these settings in "
              "each display window."));
 
-    m_lineBreaksCheck->setText(tr("Insert line break after each verse"));
     m_verseNumbersCheck->setText(tr("Show verse numbers"));
     m_headingsCheck->setText(tr("Show section headings"));
     m_scriptureReferencesCheck->setText(tr("Show scripture cross-references"));
