@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -15,10 +18,10 @@
 #include <QLabel>
 #include <QRegExp>
 #include <QTextStream>
+#include <QtGlobal>
 #include <QWidget>
 #include "../backend/drivers/cswordmoduleinfo.h"
 #include "../backend/managers/cswordbackend.h"
-#include "../bibletimeapp.h"
 #include "../frontend/messagedialog.h"
 #include "btassert.h"
 #include "cresmgr.h"
@@ -33,7 +36,6 @@ namespace tool {
  */
 bool savePlainFile(const QString & filename,
                    const QString & text,
-                   const bool forceOverwrite,
                    QTextCodec * const fileCodec)
 {
     BT_ASSERT(fileCodec);
@@ -41,21 +43,8 @@ bool savePlainFile(const QString & filename,
 
     QFile saveFile(filename);
 
-    if (saveFile.exists()) {
-        if (!forceOverwrite
-            && message::showQuestion(nullptr, QObject::tr("Overwrite File?"),
-                QString::fromLatin1("<qt><b>%1</b><br/>%2</qt>")
-                .arg( QObject::tr("The file already exists.") )
-                .arg( QObject::tr("Do you want to overwrite it?")),
-                QMessageBox::Yes | QMessageBox::No,
-                QMessageBox::No) == QMessageBox::No)
-        {
-            return false;
-        }
-        else { //either the user chose yes or forceOverwrite is set
-            saveFile.remove();
-        }
-    }
+    if (saveFile.exists())
+        saveFile.remove();
 
     if (saveFile.open(QIODevice::ReadWrite)) {
         QTextStream textstream(&saveFile);
@@ -115,7 +104,6 @@ QIcon const & getIconForModule(const CSwordModuleInfo * const module) {
                 return CResMgr::modules::book::icon_locked();
             return CResMgr::modules::book::icon_unlocked();
     }
-    return CResMgr::modules::book::icon_unlocked();
 }
 
 QLabel * explanationLabel(QWidget * const parent,
@@ -221,9 +209,15 @@ QString remoteModuleToolTip(const CSwordModuleInfo & module,
 
 int mWidth(const QWidget * const widget, const int mCount) {
     const QString mString(mCount, 'M');
+    #if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    if (widget)
+        return widget->fontMetrics().horizontalAdvance(mString);
+    return QApplication::fontMetrics().horizontalAdvance(mString);
+    #else
     if (widget)
         return widget->fontMetrics().width(mString);
     return QApplication::fontMetrics().width(mString);
+    #endif
 }
 
 
